@@ -13,8 +13,8 @@ Planet.PfreezeLower_MPa = 0.1
 Planet.PfreezeUpper_MPa = 25
 
 """ Bulk planetary settings """
-Planet.Bulk.R_m = 578.9e3
-Planet.Bulk.M_kg = 1.353e21
+Planet.Bulk.R_m = 578.9e3  # Value from mean radius in Archinal et al. (2018): https://doi.org/10.1007/s10569-017-9805-5
+Planet.Bulk.M_kg = 1.353e21  # From Jacobson et al. (1992): https://adsabs.harvard.edu/pdf/1992AJ....103.2068J
 Planet.Bulk.Tsurf_K = 60
 Planet.Bulk.Psurf_MPa = 0.0
 Planet.Bulk.Cmeasured = 0.306  # Based on rough forward models with fixed layer densities in Hussmann et al. (2006): https://doi.org/10.1016/j.icarus.2006.06.005
