@@ -6,7 +6,6 @@ from PlanetProfile.Utilities.defineStructs import Constants
 
 # Assign logger
 log = logging.getLogger('PlanetProfile')
-klugeFactor = 13.5
 
 def ElecConduct(Planet, Params):
     """ Calculate/assign electrical conductivities for each layer
@@ -83,7 +82,7 @@ def CalcElecPorIce(Planet, Params, indsLiq, indsI, indsIwet, indsII, indsIIund,
 
     # First do ocean (if present) and dry surface ice and clathrates
     if np.size(indsLiq) != 0:
-        Planet.sigma_Sm[indsLiq] = klugeFactor * Planet.Ocean.EOS.fn_sigma_Sm(Planet.P_MPa[indsLiq], Planet.T_K[indsLiq])
+        Planet.sigma_Sm[indsLiq] = Planet.Ocean.EOS.fn_sigma_Sm(Planet.P_MPa[indsLiq], Planet.T_K[indsLiq])
     if np.size(indsI) != 0:
         Planet.sigma_Sm[indsI] = Planet.Ocean.surfIceEOS['Ih'].fn_porosCorrect(Planet.Ocean.sigmaIce_Sm['Ih'], 0,
                                                                                Planet.phi_frac[indsI],
@@ -201,7 +200,7 @@ def CalcElecSolidIce(Planet, Params, indsLiq, indsI, indsII, indsIIund, indsIII,
 
     # Calculate and/or assign conductivities for each phase type
     if np.size(indsLiq) != 0:
-        Planet.sigma_Sm[indsLiq] = klugeFactor * Planet.Ocean.EOS.fn_sigma_Sm(Planet.P_MPa[indsLiq], Planet.T_K[indsLiq])
+        Planet.sigma_Sm[indsLiq] = Planet.Ocean.EOS.fn_sigma_Sm(Planet.P_MPa[indsLiq], Planet.T_K[indsLiq])
 
     Planet.sigma_Sm[indsI] = Planet.Ocean.sigmaIce_Sm['Ih']
     Planet.sigma_Sm[np.concatenate((indsII,  indsIIund))] =  Planet.Ocean.sigmaIce_Sm['II']
@@ -251,7 +250,7 @@ def CalcElecPorRock(Planet, Params, indsSil, indsSilLiq, indsSilI, indsSilII, in
     sigmaPore_Sm[indsSilV] =   Planet.Ocean.sigmaIce_Sm['V']
     sigmaPore_Sm[indsSilVI] =  Planet.Ocean.sigmaIce_Sm['VI']
     # Chop sigmaPore down to just the silicate indices
-    sigmaPore_Sm = klugeFactor * sigmaPore_Sm[indsSil]
+    sigmaPore_Sm = sigmaPore_Sm[indsSil]
 
     # Next, assign varying dependence based on porosity threshold
     belowThresh = Planet.phi_frac[indsSil] <  Planet.Sil.poreConductThresh_frac
