@@ -39,8 +39,8 @@ class PerplexEOSStruct:
                  HtidalConst_Wm3=0, porosType=None, phiTop_frac=0, Pclosure_MPa=350, phiMin_frac=None,
                  EXTRAP=False, wFeCore_ppt=None, wScore_ppt=None):
         self.comp = EOSfname[:-4]
-        self.EOSlabel = f'{self.comp}{EOSinterpMethod}{kThermConst_WmK}{HtidalConst_Wm3}{porosType}' + \
-                        f'{phiTop_frac}{Pclosure_MPa}{phiMin_frac}{EXTRAP}{wFeCore_ppt}{wScore_ppt}'
+        self.EOSlabel = f'comp{self.comp}interp{EOSinterpMethod}kTherm{kThermConst_WmK}Htidal{HtidalConst_Wm3}poros{porosType}' + \
+                        f'phi{phiTop_frac}Pclose{Pclosure_MPa}phiMin{phiMin_frac}extrap{EXTRAP}wFeppt{wFeCore_ppt}wSppt{wScore_ppt}'
         if self.EOSlabel in EOSlist.loaded.keys():
             self.ALREADY_LOADED = True
         else:
@@ -85,7 +85,8 @@ class PerplexEOSStruct:
                 P_MPa, T_K, self.ufn_rho_kgm3, self.ufn_VP_kms, self.ufn_VS_kms, \
                 self.ufn_KS_GPa, self.ufn_GS_GPa, self.ufn_Cp_JkgK, self.ufn_alpha_pK \
                     = EOSlist.loaded[tableKey]
-                self.Pmin, self.Pmax, self.Tmin, self.Tmax, self.deltaP, self.deltaT \
+                self.Pmin, self.Pmax, self.Tmin, self.Tmax, \
+                self.deltaP, self.deltaT, self.EOSdeltaP, self.EOSdeltaT \
                     = EOSlist.ranges[tableKey]
             else:
                 if '3D_EOS' in self.fpath:
@@ -121,6 +122,8 @@ class PerplexEOSStruct:
                     self.Tmax = np.max(T1D_K)
                     self.deltaP = P1D_MPa[1] - P1D_MPa[0]
                     self.deltaT = T1D_K[1] - T1D_K[0]
+                    self.EOSdeltaP = self.deltaP
+                    self.EOSdeltaT = self.deltaT
                 else:
                     # Load in Perple_X data. Note that all P, KS, and GS are stored as bar
                     firstPT, secondPT, rho_kgm3, VP_kms, VS_kms, Cp_Jm3K, alpha_pK, KS_bar, GS_bar \
@@ -154,6 +157,8 @@ class PerplexEOSStruct:
                     lenT = int(len(Tlin_K) / lenP)
                     P1D_MPa, self.deltaP = np.linspace(self.Pmin, self.Pmax, lenP, retstep=True)
                     T1D_K, self.deltaT = np.linspace(self.Tmin, self.Tmax, lenT, retstep=True)
+                    self.EOSdeltaP = self.deltaP
+                    self.EOSdeltaT = self.deltaT
 
                     # Set unphysical values to NaN so they will be caught by the next step (for all but alpha, which can cross zero)
                     rho_kgm3[rho_kgm3 <= 0] = np.nan
@@ -246,7 +251,8 @@ class PerplexEOSStruct:
 
                 EOSlist.loaded[tableKey] = (P_MPa, T_K, self.ufn_rho_kgm3, self.ufn_VP_kms, self.ufn_VS_kms,
                                               self.ufn_KS_GPa, self.ufn_GS_GPa, self.ufn_Cp_JkgK, self.ufn_alpha_pK)
-                EOSlist.ranges[tableKey] = (self.Pmin, self.Pmax, self.Tmin, self.Tmax, self.deltaP, self.deltaT)
+                EOSlist.ranges[tableKey] = (self.Pmin, self.Pmax, self.Tmin, self.Tmax, 
+                                            self.deltaP, self.deltaT, self.EOSdeltaP, self.EOSdeltaT)
 
             self.rangeLabel = f'{self.Pmin},{self.Pmax},{self.deltaP},' + \
                               f'{self.Tmin},{self.Tmax},{self.deltaT}'
@@ -346,12 +352,21 @@ class EOSwrapper:
             self.phaseID = EOSlist.loaded[self.key].phaseID
             self.POROUS = EOSlist.loaded[self.key].POROUS
         elif EOSlist.loaded[self.key].EOStype == 'ocean':
+            self.Pmin = EOSlist.loaded[self.key].Pmin
             self.Pmax = EOSlist.loaded[self.key].Pmax
+            self.Tmin = EOSlist.loaded[self.key].Tmin
+            self.Tmax = EOSlist.loaded[self.key].Tmax
+            self.deltaP = EOSlist.loaded[self.key].deltaP
+            self.deltaT = EOSlist.loaded[self.key].deltaT
+            self.EOSdeltaP = EOSlist.loaded[self.key].EOSdeltaP
+            self.EOSdeltaT = EOSlist.loaded[self.key].EOSdeltaT
+            self.comp = EOSlist.loaded[self.key].comp
+            self.w_ppt = EOSlist.loaded[self.key].w_ppt
         elif EOSlist.loaded[self.key].EOStype == 'inner':
             self.comp = EOSlist.loaded[self.key].comp
 
-    def fn_phase(self, P_MPa, T_K):
-        return EOSlist.loaded[self.key].fn_phase(P_MPa, T_K)
+    def fn_phase(self, P_MPa, T_K, grid=False):
+        return EOSlist.loaded[self.key].fn_phase(P_MPa, T_K, grid=grid)
     def fn_rho_kgm3(self, P_MPa, T_K, grid=False):
         return EOSlist.loaded[self.key].fn_rho_kgm3(P_MPa, T_K, grid=grid)
     def fn_Cp_JkgK(self, P_MPa, T_K, grid=False):
@@ -372,10 +387,10 @@ class EOSwrapper:
         return EOSlist.loaded[self.key].fn_phi_frac(P_MPa, T_K, grid=grid)
     def fn_porosCorrect(self, propBulk, propPore, phi, J):
         return EOSlist.loaded[self.key].fn_porosCorrect(propBulk, propPore, phi, J)
-    def fn_sigma_Sm(self, P_MPa, T_K):
-        return EOSlist.loaded[self.key].fn_sigma_Sm(P_MPa, T_K)
-    def fn_Seismic(self, P_MPa, T_K):
-        return EOSlist.loaded[self.key].fn_Seismic(P_MPa, T_K)
+    def fn_sigma_Sm(self, P_MPa, T_K, grid=False):
+        return EOSlist.loaded[self.key].fn_sigma_Sm(P_MPa, T_K, grid=grid)
+    def fn_Seismic(self, P_MPa, T_K, grid=False):
+        return EOSlist.loaded[self.key].fn_Seismic(P_MPa, T_K, grid=grid)
 
 
 def ResetNearestExtrap(var1, var2, min1, max1, min2, max2):
@@ -411,12 +426,15 @@ class ReturnZeros:
         self.nVar = nVar
 
     def __call__(self, P, T, grid=False):
-        nPs = np.size(P)
-        nTs = np.size(T)
-        if self.nVar > 1:
-            out = (np.zeros(np.maximum(nPs, nTs)) for _ in range(self.nVar))
+        if grid:
+            out = np.zeros((np.size(P), np.size(T)))
         else:
-            out = np.zeros(np.maximum(nPs, nTs))
+            nPs = np.size(P)
+            nTs = np.size(T)
+            if self.nVar > 1:
+                out = (np.zeros(np.maximum(nPs, nTs)) for _ in range(self.nVar))
+            else:
+                out = np.zeros(np.maximum(nPs, nTs))
         return out
 
 
@@ -454,7 +472,7 @@ def GetphiFunc(porosType, phiTop_frac, Pclosure_MPa, PREMlookup, P1D_MPa, T1D_K)
 
     # Get 2D grids of P, T values for constructing T-independent functions
     # of porosity
-    P2D_MPa, T2D_MPa = np.meshgrid(P1D_MPa, T1D_K, indexing='ij')
+    P2D_MPa, T2D_K = np.meshgrid(P1D_MPa, T1D_K, indexing='ij')
 
     if porosType == 'Han2014':
         # Han et al. (2014) porosity model: https://doi.org/10.1002/2014GL059378
